AccountResolutionResult class

Account resolution result

Constructors

AccountResolutionResult({required bool success, String? accountNumber, String? accountName, int? bankId, String? message})

Properties

accountName String?
final
accountNumber String?
final
bankId int?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited