Bank class

Bank model

Constructors

Bank({required int id, required String name, required String slug, required String code, String? longCode, String? gateway, required bool payWithBank, required bool active, String? country, String? currency, required String type})
Bank.fromJson(Map<String, dynamic> json)
factory

Properties

active bool
final
code String
final
country String?
final
currency String?
final
gateway String?
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
longCode String?
final
name String
final
payWithBank bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited