CountryListResult class

Result wrapper for a list of Country.

Constructors

CountryListResult({required bool success, required List<Country> countries, String? message})
const

Properties

count int
no setter
countries List<Country>
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited