MkLazyVideoCubit class

Constructors

MkLazyVideoCubit({Map<String, String> headers = const {}, Map<String, String> queryParameters = const {}})

Properties

currentHeaders Map<String, String>
no setter
currentQueryParameters Map<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state MkLazyVideoState
The current state.
no setterinherited
stream Stream<MkLazyVideoState>
The current stream of states.
no setterinherited

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
addHeader(String k, String v) → void
clearHeaders() → void
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
emit(MkLazyVideoState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<MkLazyVideoState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onVideoHidden(String id) → void
onVideoVisibilityChanged(String id, String url, double fraction, {Map<String, String>? headers, Map<String, String>? queryParameters}) Future<void>
pauseAll() → void
removeHeader(String k) → void
setHeaders(Map<String, String> h) → void
setQueryParameters(Map<String, String> p) → void
togglePlayPause(String id) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited