TokenRefreshResult class
Token refresh result
Constructors
- TokenRefreshResult.failed(String message)
-
factory
- TokenRefreshResult.noRefreshToken()
-
factory
- TokenRefreshResult.refreshTokenExpired()
-
factory
- TokenRefreshResult.success()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldReLogin → bool
-
Should force user to re-login
no setter
- status → TokenRefreshStatus
-
final
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited