CountryCity class
A city within a state/country.
- Annotations
Constructors
- CountryCity({required String name, String? stateCode, String? countryCode})
-
const
-
CountryCity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- countryCode → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateCode → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited