MkVideoPreloadState<T> class
abstract
- Implemented types
- Available extensions
- Annotations
-
- @freezed
Constructors
- MkVideoPreloadState.error(String message)
-
constfactory
- MkVideoPreloadState.initial()
-
constfactory
- MkVideoPreloadState.loading({required int currentIndex})
-
constfactory
-
MkVideoPreloadState.ready({required int currentIndex, required String currentItemId, required Map<
String, Player> players, required Map<String, VideoController> controllers, required List<MkVideoItem< items, @Default.new(true) bool isPlaying, @Default.new(false) bool isMuted, @Default.new(true) bool isExpanded})T> > -
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
map<
TResult extends Object?> ({required TResult initial(_MkInitial< T> value), required TResult loading(_MkLoading<T> value), required TResult ready(_MkReady<T> value), required TResult error(_MkError<T> value)}) → TResult -
Available on MkVideoPreloadState<
AT> , provided by the MkVideoPreloadStatePatterns extensionswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> ({TResult? initial(_MkInitial< T> value)?, TResult? loading(_MkLoading<T> value)?, TResult? ready(_MkReady<T> value)?, TResult? error(_MkError<T> value)?}) → TResult? -
Available on MkVideoPreloadState<
A variant ofT> , provided by the MkVideoPreloadStatePatterns extensionmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> ({TResult initial(_MkInitial< T> value)?, TResult loading(_MkLoading<T> value)?, TResult ready(_MkReady<T> value)?, TResult error(_MkError<T> value)?, required TResult orElse()}) → TResult -
Available on MkVideoPreloadState<
A variant ofT> , provided by the MkVideoPreloadStatePatterns extensionmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> ({TResult initial()?, TResult loading(int currentIndex)?, TResult ready(int currentIndex, String currentItemId, Map< String, Player> players, Map<String, VideoController> controllers, List<MkVideoItem< items, bool isPlaying, bool isMuted, bool isExpanded)?, TResult error(String message)?, required TResult orElse()}) → TResultT> > -
Available on MkVideoPreloadState<
A variant ofT> , provided by the MkVideoPreloadStatePatterns extensionwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
when<
TResult extends Object?> ({required TResult initial(), required TResult loading(int currentIndex), required TResult ready(int currentIndex, String currentItemId, Map< String, Player> players, Map<String, VideoController> controllers, List<MkVideoItem< items, bool isPlaying, bool isMuted, bool isExpanded), required TResult error(String message)}) → TResultT> > -
Available on MkVideoPreloadState<
AT> , provided by the MkVideoPreloadStatePatterns extensionswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> ({TResult? initial()?, TResult? loading(int currentIndex)?, TResult? ready(int currentIndex, String currentItemId, Map< String, Player> players, Map<String, VideoController> controllers, List<MkVideoItem< items, bool isPlaying, bool isMuted, bool isExpanded)?, TResult? error(String message)?}) → TResult?T> > -
Available on MkVideoPreloadState<
A variant ofT> , provided by the MkVideoPreloadStatePatterns extensionwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited